@@ -2,7 +2,6 @@ from __future__ import annotations
 
 import asyncio
 import inspect
-import logging
 import pathlib
 from typing import Any, BinaryIO, Union
 
@@ -12,13 +11,12 @@ from glQiwiApi.utils.compat import aiofiles
 CHUNK_SIZE = 65536
 
 StrOrBytesPath = Union[str, bytes, pathlib.Path]  # stable
-AnyPath = StrOrBytesPath  # obsolete, will be removed soon
 
 _OpenFile = Union[StrOrBytesPath, int]
 
 
 class File:
-    def __init__(self, input: AbstractInput[Any]) -> None:  # noqa
+    def __init__(self, input: AbstractInput[Any]) -> None:
         self._input = input
 
     def get_filename(self) -> str:
@@ -30,7 +28,7 @@ class File:
     def get_path(self) -> str:
         return self._input.get_path()
 
-    def save(self, path: AnyPath, chunk_size: int = CHUNK_SIZE) -> None:
+    def save(self, path: StrOrBytesPath, chunk_size: int = CHUNK_SIZE) -> None:
         file_descriptor = self.get_underlying_file_descriptor()
         with open(path, "wb") as fp:
             while True:
@@ -43,7 +41,9 @@ class File:
         if file_descriptor.seekable():
             file_descriptor.seek(0)
 
-    async def save_asynchronously(self, path: AnyPath, chunk_size: int = CHUNK_SIZE) -> None:
+    async def save_asynchronously(
+        self, path: StrOrBytesPath, chunk_size: int = CHUNK_SIZE
+    ) -> None:
         file_descriptor = self.get_underlying_file_descriptor()
         async with aiofiles.open(path, "wb") as fp:
             while True:
@@ -60,15 +60,14 @@ class File:
         try:
             return self.get_filename()
         except TypeError:
-            # it determines, that input is binary stream
-            return "<File>"
+            return "<File(binary stream underlies)>"
 
     def __del__(self) -> None:
         if not hasattr(self, "_input"):
             return
 
         if inspect.iscoroutinefunction(self._input.close()):  # type: ignore  # noqa
-            return asyncio.ensure_future(self._file.close())  # type: ignore  # noqa
+            return asyncio.ensure_future(self._input.close())  # type: ignore # noqa
         self._input.close()
 
     __repr__ = __str__
